;-------------------Pixler--------------------;
;                                             ;
;  Inputs:                                    ;
;    _pixler_x                                ;
;       • specifies the X coordinate of the   ;
;         of the pixel or sprite to draw      ; 
;    _pixler_y                                ;
;       • specifies the Y coordinate of the   ;
;         of the pixel or sprite to draw      ;  
;    _pixler_do_sprite                        ;
;       • load with 1 to draw sprite or load  ;
;         with 0 to print a pixel (default 0) ;
;    DE register                              ;
;       • zero-terminating bytes to represent ;
;         the sprite to be drawn              ;
;                                             ;
;                           by Amelia Hartman ;
;--------------------Pixler-------------------;

printPixel:
	ld hl, plotSScreen
	
	ld a, (_pixler_y)
	cp 0
	call nz, _pixler_incrementY

	ld a, (_pixler_x)
	cp 8
	call nc, _pixler_incrementX

	ld a, (_pixler_do_sprite)
	cp 1
	jp z, _printSprite

	ld a, (_pixler_x)
	cp 0
	call z, _pixler_x0
	ld a, (_pixler_x)
	cp 1
	call z, _pixler_x1
	ld a, (_pixler_x)
	cp 2
	call z, _pixler_x2
	ld a, (_pixler_x)
	cp 3
	call z, _pixler_x3
	ld a, (_pixler_x)
	cp 4
	call z, _pixler_x4
	ld a, (_pixler_x)
	cp 5
	call z, _pixler_x5
	ld a, (_pixler_x)
	cp 6
	call z, _pixler_x6
	ld a, (_pixler_x)
	cp 7
	call z, _pixler_x7

	ret

_printSprite:	
	ld a, (de)
	or (hl)
	ld (hl), a

	inc de
	ld b, 12
	call _moveOver

	ld a, (de)
	cp 00000000h
	jp nz, _printSprite

	ld a, 0		
	ld (_pixler_do_sprite), a

	ret

_pixler_incrementX: 
	ld b, 1
	call _moveOver
	ld a, (_pixler_x)
	add a, -8
	ld (_pixler_x), a
	ld a, (_pixler_x)
	cp 8
	jp nc, _pixler_incrementX
	ret

_pixler_incrementY:
	ld b, 12
	call _moveOver
	ld a, (_pixler_y)
	add a, -1
	ld (_pixler_y), a
	ld a, (_pixler_y)
	cp 0
	jp nz, _pixler_incrementY
	ret
_pixler_x0:
	ld a, 10000000b
	or (hl)
	ld (hl), a
	ret
_pixler_x1:
	ld a, 01000000b
	or (hl)
	ld (hl), a
	ret
_pixler_x2:
	ld a, 00100000b
	or (hl)
	ld (hl), a
	ret
_pixler_x3:
	ld a, 00010000b
	or (hl)
	ld (hl), a
	ret
_pixler_x4:
	ld a, 00001000b
	or (hl)
	ld (hl), a
	ret
_pixler_x5:
	ld a, 00000100b
	or (hl)
	ld (hl), a
	ret
_pixler_x6:
	ld a, 00000010b
	or (hl)
	ld (hl), a
	ret
_pixler_x7:
	ld a, 00000001b
	or (hl)
	ld (hl), a
	ret

_moveOver: 
	ld a, 0
	ld (_pixler_i), a

_moveOver_loop:
	inc hl

	ld a, (_pixler_i)
	add a, 1
	ld (_pixler_i), a
	cp b
	jp nz, _moveOver_loop

	ret

drawBuffer:
	bcall(_GrBufCpy)
	ret

clearPixels:
	ld hl, plotSScreen
	ld a, 192
	ld (_pixler_i), a


_clrPixels_loop:
	
	ld a, 00000000b
	ld (hl), a
	inc hl
	ld (hl), a
	inc hl
	ld (hl), a
	inc hl
	ld (hl), a
	inc hl
	ld a, (_pixler_i)
	cp 0
	add a, -1
	ld (_pixler_i), a
	jp nz, _clrPixels_loop

	ret

;                                             ;
; Inputs: A, B                                ;
; Outputs: A (the result), B (the remainder)  ;
; Destroys: C, D                              ;
;                                             ;
DivAByB:
	ld c,0
_DivAByB_Loop:
	inc c
	sub b
	cp b         
	jp nc, _DivAByB_Loop
	ld d,a
	ld a,c
	ld b,d
	ld c,0
	ld d,0
	ret

;                                             ;
; Inputs: A, B                                ;
; Outputs: A (the result),                    ;
; Destroys: B, C, D, E                        ;
;                                             ;
MulAByB:
	ld c, 0
_MulAByB_Loop:
	dec b
	ld e, a
	ld a, c
	add a, e
	ld c, a
	ld a, e
	ld d, a
	ld a, b
	cp 0
	ld a, d
	jp nz, _MulAByB_Loop
	ld a, c
	ld b, 0
	ld c, 0
	ld d, 0
	ld e, 0
	ret
	

;                                   ;
; Inputs: A                         ;
; Outputs: HL (address of string)   ;
; Destroys: A, B, C, D              ;
;                                   ;
AToString:
	ld hl, AToString_str

	cp 100
	jp nc, AToString_3Digits
	cp 10
	jp nc, AToString_2Digits
	add a,30h
	ld (hl), a
	inc hl
	ld (hl),00
	dec hl
	jp AToString_End

AToString_3Digits:
	ld b,100
	call DivAByB
	add a, 30h
	ld (hl), a
	ld a, b
	cp 10
	jp c, AToString_3Digits_2Digits
	ld b, 10
	call DivAByB
	inc hl
	add a, 30h
	ld (hl), a
	inc hl
	ld a, b
	add a, 30h
	ld (hl), a
	dec hl
	dec hl
	jp AToString_End
AToString_3Digits_2Digits:
	inc hl
	ld (hl), 30h
	add a, 30h
	inc hl
	ld (hl), a
	dec hl
	dec hl
	jp AToString_End
AToString_2Digits:
	ld b,10
	call DivAByB
	add a, 30h
	ld (hl),a
	inc hl
	ld a, b
	add a, 30h
	ld (hl), a
	dec hl

	inc hl
	inc hl
	ld (hl), 00
	dec hl
	dec hl
AToString_End:
	ld b,0
	ret

;                                   ;
; Inputs: A                         ;
; Outputs: B                        ;
; Destroys: A, B, C, D              ;
;                                   ;
getRand:
	ld b, a
	ld a, (intSeed)
	call DivAByB
	inc b
	ret

updateSeed:
	ld a, (intSeed)
	ld b, 3
	call MulAByB
	add a, 1
	ld (intSeed), a	
	ret

intSeed:
	.db 54

AToString_str:
	.db 0,0,0,0,0,0,0,0

_pixler_tmp:
	.db 0

_pixler_do_sprite:
	.db 0

_pixler_i:
	.db 0

_pixler_x:
	.db 0

_pixler_y:
	.db 0

